ENTER Key Configuration — CKEditor Sample

# CKEditor Samples » ENTER Key Configuration

This sample shows how to configure the Enter and Shift+Enter keys to perform actions specified in the `enterMode` and `shiftEnterMode` parameters, respectively. You can choose from the following options:

- `ENTER_P` – new `<p>` paragraphs are created;
- `ENTER_BR` – lines are broken with `<br>` elements;
- `ENTER_DIV` – new `<div>` blocks are created.

The sample code below shows how to configure CKEditor to create a `<div>` block when Enter key is pressed.

    CKEDITOR.replace( 'textarea_id', {
    	enterMode: CKEDITOR.ENTER_DIV
    });

Note that `textarea_id` in the code above is the `id` attribute of the `<textarea>` element to be replaced.

When Enter is pressed:
When Shift+Enter is pressed:

This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.